"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getVideoLocalViewerValidator = exports.videoViewValidator = void 0;
const tslib_1 = require("tslib");
const express_validator_1 = require("express-validator");
const video_view_1 = require("../../../helpers/custom-validators/video-view");
const local_video_viewer_1 = require("../../../models/view/local-video-viewer");
const misc_1 = require("../../../helpers/custom-validators/misc");
const logger_1 = require("../../../helpers/logger");
const shared_1 = require("../shared");
const getVideoLocalViewerValidator = [
    (0, express_validator_1.param)('localViewerId')
        .custom(misc_1.isIdValid).withMessage('Should have a valid local viewer id'),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        logger_1.logger.debug('Checking getVideoLocalViewerValidator parameters', { parameters: req.params });
        if ((0, shared_1.areValidationErrors)(req, res))
            return;
        const localViewer = yield local_video_viewer_1.LocalVideoViewerModel.loadFullById(+req.params.localViewerId);
        if (!localViewer) {
            return res.fail({
                status: 404,
                message: 'Local viewer not found'
            });
        }
        res.locals.localViewerFull = localViewer;
        return next();
    })
];
exports.getVideoLocalViewerValidator = getVideoLocalViewerValidator;
const videoViewValidator = [
    (0, shared_1.isValidVideoIdParam)('videoId'),
    (0, express_validator_1.body)('currentTime')
        .optional()
        .customSanitizer(misc_1.toIntOrNull)
        .custom(misc_1.isIntOrNull).withMessage('Should have correct current time'),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        logger_1.logger.debug('Checking videoView parameters', { parameters: req.body });
        if ((0, shared_1.areValidationErrors)(req, res))
            return;
        if (!(yield (0, shared_1.doesVideoExist)(req.params.videoId, res, 'only-video')))
            return;
        const video = res.locals.onlyVideo;
        const videoDuration = video.isLive
            ? undefined
            : video.duration;
        if (!(0, misc_1.exists)(req.body.currentTime)) {
            req.body.currentTime = Math.min(videoDuration !== null && videoDuration !== void 0 ? videoDuration : 0, 30);
        }
        const currentTime = req.body.currentTime;
        if (!(0, video_view_1.isVideoTimeValid)(currentTime, videoDuration)) {
            return res.fail({
                status: 400,
                message: 'Current time is invalid'
            });
        }
        return next();
    })
];
exports.videoViewValidator = videoViewValidator;
//# sourceMappingURL=video-view.js.map