"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkLiveCleanup = void 0;
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
function checkLiveCleanup(server, videoUUID, savedResolutions = []) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let live;
        try {
            live = yield server.live.get({ videoId: videoUUID });
        }
        catch (_a) { }
        const basePath = server.servers.buildDirectory('streaming-playlists');
        const hlsPath = (0, path_1.join)(basePath, 'hls', videoUUID);
        if (savedResolutions.length === 0) {
            if (live === null || live === void 0 ? void 0 : live.permanentLive) {
                (0, chai_1.expect)(yield (0, fs_extra_1.pathExists)(hlsPath)).to.be.true;
                const hlsFiles = yield (0, fs_extra_1.readdir)(hlsPath);
                (0, chai_1.expect)(hlsFiles).to.have.lengthOf(1);
                const replayDir = (0, path_1.join)(hlsPath, 'replay');
                (0, chai_1.expect)(yield (0, fs_extra_1.pathExists)(replayDir)).to.be.true;
                const replayFiles = yield (0, fs_extra_1.readdir)((0, path_1.join)(hlsPath, 'replay'));
                (0, chai_1.expect)(replayFiles).to.have.lengthOf(0);
            }
            else {
                (0, chai_1.expect)(yield (0, fs_extra_1.pathExists)(hlsPath)).to.be.false;
            }
            return;
        }
        const files = yield (0, fs_extra_1.readdir)(hlsPath);
        (0, chai_1.expect)(files).to.have.lengthOf(savedResolutions.length * 2 + 2);
        for (const resolution of savedResolutions) {
            const fragmentedFile = files.find(f => f.endsWith(`-${resolution}-fragmented.mp4`));
            (0, chai_1.expect)(fragmentedFile).to.exist;
            const playlistFile = files.find(f => f.endsWith(`${resolution}.m3u8`));
            (0, chai_1.expect)(playlistFile).to.exist;
        }
        const masterPlaylistFile = files.find(f => f.endsWith('-master.m3u8'));
        (0, chai_1.expect)(masterPlaylistFile).to.exist;
        const shaFile = files.find(f => f.endsWith('-segments-sha256.json'));
        (0, chai_1.expect)(shaFile).to.exist;
    });
}
exports.checkLiveCleanup = checkLiveCleanup;
//# sourceMappingURL=live.js.map